"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Summary = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const format_1 = require("./../libs/format");
const events_manager_1 = require("./../managers/events-manager");
class Summary {
    logger;
    count = {
        init: 0,
        exec: 0,
        dispose: 0,
    };
    time = {
        init: 0,
        exec: 0,
        dispose: 0,
        execution: 0
    };
    #isHelp = false;
    constructor(logger) {
        this.logger = logger;
        events_manager_1.globalEvent
            .on('element/exec', () => {
            this.count.exec++;
        })
            .on('element/init', () => {
            this.count.init++;
        })
            .on('element/dispose', () => {
            this.count.dispose++;
        })
            .on('scene/init:before', () => {
            this.time.init = Date.now();
            this.time.execution = Date.now();
        })
            .on('scene/init:end', () => {
            this.time.init = Date.now() - this.time.init;
        })
            .on('scene/exec:before', () => {
            this.time.exec = Date.now();
        })
            .on('scene/exec:end', () => {
            this.time.exec = Date.now() - this.time.exec;
        })
            .on('scene/dispose:before', () => {
            this.time.dispose = Date.now();
        })
            .on('scene/dispose:end', () => {
            this.time.dispose = Date.now() - this.time.dispose;
        });
    }
    async start() {
        const { name, version } = await Promise.resolve().then(() => __importStar(require('../../package.json')));
        this.logger.log(`%s\t%s`, ansi_colors_1.default.yellow.bold(`${name}⚡️`), ansi_colors_1.default.gray.italic(`v${version}`));
        this.logger.log('');
    }
    help() {
        this.#isHelp = true;
        this.logger.log(`┌
  Usage: ezrun|r [file] [password]

  Arguments:
    file    \t\t Path of the scene file to run (required)
    password\t\t Password to decrypt the scene 
  
  Informations:
  ✔ Github project: https://github.com/doanthuanthanh88/ezrun 
  ✔ Npm package   : https://www.npmjs.com/package/ezrun
  ✔ Docker Image  : https://hub.docker.com/repository/docker/doanthuanthanh88/ezrun
└`);
    }
    stop() {
    }
    print() {
        if (this.#isHelp)
            return;
        this.logger.debug('');
        this.logger.debug(ansi_colors_1.default.gray('»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»»'));
        this.logger.debug(`%s\t%s`, 'Runs    ', `${this.count.exec}(items)`);
        this.logger.debug(`%s\t%s`, 'Duration', `${(0, format_1.formatDuration)(Date.now() - this.time.execution)}`);
        this.logger.debug(ansi_colors_1.default.gray(`          \t ↳ %s\t%d(items) in %s`), 'initial', this.count.init, (0, format_1.formatDuration)(this.time.init));
        this.logger.debug(ansi_colors_1.default.gray(`          \t ↳ %s\t%d(items) in %s`), 'execute', this.count.exec, (0, format_1.formatDuration)(this.time.exec));
        this.logger.debug(ansi_colors_1.default.gray(`          \t ↳ %s\t%d(items) in %s`), 'dispose', this.count.dispose, (0, format_1.formatDuration)(this.time.dispose));
        this.logger.debug(ansi_colors_1.default.gray('«««««««««««««««««««««««««««««««««««««««««««««««««««««««««««««««'));
    }
}
exports.Summary = Summary;
//# sourceMappingURL=summary.js.map