"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const fs_1 = require("fs");
const promises_1 = require("fs/promises");
const path_1 = require("path");
const variables_manager_1 = require("../../managers/variables-manager");
const md_file_output_1 = require("./parser/md-file-output");
const md_file_parser_1 = require("./parser/md-file-parser");
class MDDoc {
    title;
    saveTo;
    includeDirs;
    excludeDirs;
    includePattern;
    logger;
    prependMDs;
    appendMDs;
    #mdFileOutput;
    async init(props) {
        if (!Array.isArray(props.includeDirs))
            props.includeDirs = [props.includeDirs];
        if (!Array.isArray(props.excludeDirs))
            props.excludeDirs = [props.excludeDirs];
        if (props.includePattern)
            props.includePattern = new RegExp(props.includePattern);
        Object.assign(this, props);
    }
    async exec() {
        this.logger.debugBlock(true);
        if (this.includeDirs)
            this.includeDirs = this.includeDirs.map(dir => variables_manager_1.GlobalUtils.getPath(dir));
        if (this.saveTo)
            this.saveTo = variables_manager_1.GlobalUtils.getPath(this.saveTo);
        this.#mdFileOutput = new md_file_output_1.MDFileOutput(this.title);
        await Promise.all(this.includeDirs.map(dirPath => this.scanDir(dirPath)));
        this.#mdFileOutput.scanDone();
        const preContents = await Promise.all(this.prependMDs?.map(async (opt) => {
            if (typeof opt === 'string')
                return opt;
            const buf = await (0, promises_1.readFile)(opt.path);
            return buf.toString('utf8');
        }) || []);
        this.#mdFileOutput.prependContent(...preContents);
        const postContents = await Promise.all(this.appendMDs?.map(async (opt) => {
            if (typeof opt === 'string')
                return opt;
            const buf = await (0, promises_1.readFile)(opt.path);
            return buf.toString('utf8');
        }) || []);
        this.#mdFileOutput.appendContent(...postContents);
        this.#mdFileOutput.save(this.saveTo);
        this.logger.debugBlock(false);
    }
    async dispose() { }
    async scanDir(dirPath) {
        if (this.excludeDirs.find(e => dirPath.includes(e)) || !this.includePattern.test(dirPath))
            return;
        if ((0, fs_1.statSync)(dirPath).isFile()) {
            const isGot = await this.scanFile(dirPath);
            if (isGot) {
                this.logger.debug(`%s %s`, ansi_colors_1.default.green('✓'), ansi_colors_1.default.gray(dirPath));
            }
            else {
                this.logger.debug(`%s %s`, ansi_colors_1.default.red('✗'), ansi_colors_1.default.gray(dirPath));
            }
        }
        else {
            const items = await (0, promises_1.readdir)(dirPath);
            await Promise.all(items.map(itemPath => this.scanDir((0, path_1.join)(dirPath, itemPath))));
        }
    }
    async scanFile(filePath) {
        const mdFileParser = new md_file_parser_1.MDFileParser(filePath);
        const rs = await mdFileParser.analystic();
        this.#mdFileOutput.addMDFileParser(mdFileParser);
        return !!rs.length;
    }
}
exports.default = MDDoc;
//# sourceMappingURL=md.js.map