"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MDFileOutput = void 0;
const fs_1 = require("fs");
const promises_1 = require("fs/promises");
class MDFileOutput {
    mdFileParsers = [];
    mdFileProps = {
        top: [],
        default: [],
        bottom: [],
    };
    content = [];
    constructor(title) {
        if (title)
            this.content.push(`# ${title}`, '');
    }
    addMDFileParser(m) {
        this.mdFileParsers.push(m);
    }
    scanDone() {
        this.mdFileParsers.reduce((sum, e) => {
            sum.default.push(...e.result.flat().filter(e => !e.position));
            sum.top.push(...e.result.flat().filter(e => e.position === 'top'));
            sum.bottom.push(...e.result.flat().filter(e => e.position === 'bottom'));
            return sum;
        }, this.mdFileProps);
        this.mdFileProps.bottom.sort((a, b) => (a.order - b.order) || (a.title.localeCompare(b.title)));
        this.mdFileProps.top.sort((a, b) => (a.order - b.order) || (a.title.localeCompare(b.title)));
        this.mdFileProps.default.sort((a, b) => (a.order - b.order) || (a.title.localeCompare(b.title)));
        this.content.push(`| Tags | Description |`);
        this.content.push(`|---|---|`);
        this.content.push(...this.mdFileProps.default.map(md => md.toMenu()));
        this.content.push('');
        this.content.push(...this.mdFileProps.top.map(md => md.toMD()));
        this.content.push('');
        this.content.push(...this.mdFileProps.default.map(md => md.toMD()));
        this.content.push('');
        this.content.push(...this.mdFileProps.bottom.map(md => md.toMD()));
    }
    appendContent(...content) {
        this.content.push(...content);
    }
    appendFile(file) {
        return this.appendContent((0, fs_1.readFileSync)(file).toString('utf8'));
    }
    prependContent(...content) {
        this.content = [...content, ...this.content];
    }
    prependFile(file) {
        return this.prependContent((0, fs_1.readFileSync)(file).toString('utf8'));
    }
    async save(path) {
        await (0, promises_1.writeFile)(path, this.content.join('\n'));
    }
}
exports.MDFileOutput = MDFileOutput;
//# sourceMappingURL=md-file-output.js.map