"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MDFileParser = exports.MDFileProps = void 0;
const fs_1 = require("fs");
const promises_1 = __importDefault(require("readline/promises"));
class MDFileProps {
    title;
    description;
    example;
    order;
    tag;
    position;
    constructor() {
        this.order = 999;
    }
    toMenu() {
        return `| [${this.title}](#${this.title}) | ${this.description} |`;
    }
    toMD() {
        return `
## <a id="${this.title}"></a>${this.title}  
${this.tag ? `\`${this.tag}\`` : ''}  
${this.description}  

Example:  
${this.example}  
`;
    }
}
exports.MDFileProps = MDFileProps;
class MDFileParser {
    filePath;
    result = [];
    constructor(filePath) {
        this.filePath = filePath;
    }
    async analystic() {
        const rl = promises_1.default.createInterface({
            input: (0, fs_1.createReadStream)(this.filePath),
            crlfDelay: Infinity
        });
        let isStart = false;
        let mdBlock;
        let cur;
        let space = undefined;
        for await (let line of rl) {
            if (!isStart) {
                line = line.trimStart();
                if (!line.startsWith('/**|**'))
                    continue;
                isStart = true;
                mdBlock = new MDFileProps();
                mdBlock.title = line.replace('/**|**', '').trim();
                cur = 'des';
                continue;
            }
            if (space === undefined)
                space = (line.match(/^(\s*).+/)[1]);
            line = line.replace(new RegExp(`^${space}`), '');
            const m = line.match(new RegExp(`^@(\\w+)( (.*))?\\s*$`));
            if (m) {
                cur = m[1];
                line = m[3] || '';
                mdBlock[cur] = line;
                continue;
            }
            if (cur === 'des') {
                if (!mdBlock.description)
                    mdBlock.description = '';
                else
                    mdBlock.description += '\n';
                mdBlock.description += line.trimStart();
                continue;
            }
            if (line.trimStart().startsWith('*/')) {
                isStart = false;
                space = undefined;
                this.result.push(mdBlock);
                continue;
            }
            if (cur) {
                mdBlock[cur] += ('\n' + line);
            }
            continue;
        }
        return this.result;
    }
}
exports.MDFileParser = MDFileParser;
//# sourceMappingURL=md-file-parser.js.map