"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const variables_manager_1 = require("../../managers/variables-manager");
const group_1 = __importDefault(require("../group"));
const echo_1 = __importDefault(require("./echo"));
let echo;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    echo = testing_1.ElementTest.create(echo_1.default);
});
afterEach(async () => {
    await echo.dispose();
});
test('pass string in echo', async () => {
    variables_manager_1.GlobalVars.name = 'world';
    await echo.init('Hello ${vars.name}');
    const rs = await echo.exec();
    expect(rs).toBe(`Hello ${variables_manager_1.GlobalVars.name}`);
});
test('pass object in echo', async () => {
    variables_manager_1.GlobalVars.name = 'world';
    await echo.init({
        content: { txt: 'Hello ${vars.name}' }
    });
    const rs = await echo.exec();
    expect(rs).toEqual({
        txt: `Hello ${variables_manager_1.GlobalVars.name}`
    });
});
test('quick print text with color', async () => {
    const group = testing_1.ElementTest.create(group_1.default);
    let echo = [];
    group.on('item/created', item => {
        echo.push(item);
    });
    await group.init([
        {
            "echo'blue": 'blue here'
        },
        {
            "echo'red": 'red here'
        }
    ]);
    await group.exec();
    expect(echo[0].style).toBe('blue');
    expect(echo[1].style).toBe('red');
});
//# sourceMappingURL=echo.spec.js.map