"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a, _b;
Object.defineProperty(exports, "__esModule", { value: true });
exports.createElement = exports.loadElementClass = exports.setVarsAfterExec = exports.applyVarsBeforeExec = exports.markElementNeedReplace = exports.getElementLoop = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const packages_manager_1 = require("./../managers/packages-manager");
const tags_manager_1 = require("./../managers/tags-manager");
const templates_manager_1 = require("./../managers/templates-manager");
const variables_manager_1 = require("./../managers/variables-manager");
const events_manager_1 = require("../managers/events-manager");
const IgnoreVarsBeforeExec = ['vars', 'getContextVar', 'setContextVarsString', 'setContextVarsObject', 'ignoreVarsBeforeExec', 'logger', 'parent', 'if'];
const EVAL_EXPS_KEY = Symbol('EvalExps');
async function getElementLoop(loop) {
    if (loop === undefined)
        return undefined;
    const loopCondition = await (0, variables_manager_1.getVars)(loop);
    return loopCondition;
}
exports.getElementLoop = getElementLoop;
async function markElementNeedReplace(elem) {
    const props = Object.keys(elem);
    let ignoreVarsBeforeExec = [...IgnoreVarsBeforeExec];
    if (elem.ignoreVarsBeforeExec) {
        ignoreVarsBeforeExec.push(...elem.ignoreVarsBeforeExec);
    }
    elem[EVAL_EXPS_KEY] = props.filter(key => {
        return !ignoreVarsBeforeExec.includes(key) && (0, variables_manager_1.isGetEvalExp)(elem[key]);
    });
}
exports.markElementNeedReplace = markElementNeedReplace;
async function applyVarsBeforeExec(elem, ...props) {
    const evalExps = props?.length ? props : elem[EVAL_EXPS_KEY];
    await Promise.all(evalExps.map(async (key) => elem[key] = await (0, variables_manager_1.getVars)(elem[key], elem.getContextVar || elem)));
}
exports.applyVarsBeforeExec = applyVarsBeforeExec;
async function setVarsAfterExec(elem, logger) {
    if (elem['vars']) {
        const keys = await (0, variables_manager_1.setVars)(elem['vars'], elem.setContextVarsString, elem.setContextVarsObject);
        logger.trace(`[vars] \t%j`, keys.reduce((sum, e) => {
            sum[e] = variables_manager_1.GlobalVars[e];
            return sum;
        }, {}));
    }
}
exports.setVarsAfterExec = setVarsAfterExec;
async function loadElementClass(name, logger) {
    let ElementClazz;
    const [path, className = 'default'] = name.split(tags_manager_1.ClassInFileCharacter);
    let triedToInstall = false;
    do {
        const errors = [];
        try {
            const Clazz = (await (_a = `./${path}`, Promise.resolve().then(() => __importStar(require(_a)))));
            ElementClazz = Clazz[className];
        }
        catch (err) {
            errors.push(err);
            try {
                const Clazz = await (_b = path, Promise.resolve().then(() => __importStar(require(_b))));
                ElementClazz = Clazz[className];
            }
            catch (err) {
                errors.push(err);
                try {
                    ElementClazz = await tags_manager_1.tagsManager.getTag(path, className);
                }
                catch (err) {
                    errors.push(err);
                }
            }
        }
        if (ElementClazz) {
            if (!ElementClazz.prototype) {
                if (typeof ElementClazz === 'function') {
                    ElementClazz = await ElementClazz();
                }
                else {
                    return function () {
                        Object.assign(this, ElementClazz);
                    };
                }
            }
            if (!ElementClazz)
                throw new Error(`Could not found the tag "${path}.${className}"`);
            return ElementClazz;
        }
        if (triedToInstall) {
            errors.forEach(err => logger.error(err?.message));
            throw new Error(`Could not found class "${className}" in "${path}"`);
        }
        triedToInstall = true;
        const packageManager = new packages_manager_1.PackagesManager(logger);
        await packageManager.install(path);
    } while (true);
}
exports.loadElementClass = loadElementClass;
function createElement(ElementClazz, ...args) {
    const elem = new ElementClazz(...args);
    elem['$$extend'] = function (ids) {
        if (!ids?.length)
            return;
        if (typeof ids === 'string')
            ids = [ids];
        const props = {};
        ids.forEach(id => {
            const cached = templates_manager_1.templatesManager.getFromCached(id);
            (0, lodash_merge_1.default)(props, cached);
        });
        return props;
    };
    elem['$$export'] = function (id, props) {
        if (!id)
            return;
        templates_manager_1.templatesManager.pushToCached(id, props);
        this.logger.trace(`->    \t%s`, id);
    };
    elem['$$clone'] = function (parent) {
        const newElement = (0, lodash_clonedeep_1.default)(this);
        newElement.parent = parent;
        return newElement;
    };
    elem.findParentWithType = function (ClazzType) {
        let parent = this.parent;
        do {
            if (parent instanceof ClazzType)
                return parent;
        } while (parent = parent['parent']);
        return parent;
    };
    const init = elem.init;
    elem.init = async function (elemProps) {
        events_manager_1.globalEvent.emit('element/init');
        if (elemProps && typeof elemProps === 'object' && !Array.isArray(elemProps)) {
            let { ignore, '<-': inheritKeys, '->': exposeKey, ...eProps } = elemProps;
            if (inheritKeys)
                (0, lodash_merge_1.default)(eProps, this['$$extend'](inheritKeys));
            if (exposeKey)
                this['$$export'](exposeKey, (0, lodash_clonedeep_1.default)(eProps));
            elemProps = eProps;
            if (elemProps.if !== undefined)
                this.if = elemProps.if;
            if (elemProps.loop !== undefined)
                this.loop = elemProps.loop;
            if (elemProps.async !== undefined)
                this.async = elemProps.async;
            if (elemProps.ignoreError !== undefined)
                this.ignoreError = elemProps.ignoreError;
            if (elemProps.log)
                this.logger.setLevel(elemProps.log);
            if (ignore !== undefined)
                this.ignore = ignore;
            this.parent?.title && this.logger.addIndent(1);
        }
        await init.call(this, elemProps);
        markElementNeedReplace(this);
    };
    elem['$$prepare'] = async function () {
        if (elem.if === undefined)
            return true;
        await applyVarsBeforeExec(this, 'if');
        return !!this.if;
    };
    const exec = elem.exec;
    elem.exec = async function (parentData) {
        this.parentData = parentData;
        try {
            events_manager_1.globalEvent.emit('element/exec');
            await applyVarsBeforeExec(this);
            this.title && this.logger.info(`%s`, this.title);
            this.setContextVarsString = await exec.call(this, parentData);
        }
        catch (err) {
            this.error = err;
            if (!this.ignoreError)
                throw this.error;
            this.logger.debug(ansi_colors_1.default.yellow(`⚠️ ${this.error?.message || this.error}`));
        }
        this.setContextVarsObject = this;
        await setVarsAfterExec(this, this.logger);
        return this.setContextVarsString;
    };
    const dispose = elem.dispose;
    elem.dispose = async function () {
        events_manager_1.globalEvent.emit('element/dispose');
        await dispose.call(this);
    };
    return elem;
}
exports.createElement = createElement;
//# sourceMappingURL=element.utils.js.map