"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const variables_manager_1 = require("../../managers/variables-manager");
class Exec {
    title;
    commands;
    logger;
    async init(props) {
        if (Array.isArray(props)) {
            this.commands = props;
        }
        else {
            Object.assign(this, props);
        }
    }
    async exec() {
        try {
            this.logger.debugBlock(true);
            const rs = await new Promise((resolve, reject) => {
                this.logger.debug(this.commands.join(' '));
                const [bin, ...args] = this.commands;
                const c = (0, child_process_1.spawn)(bin, args, { env: process.env, cwd: variables_manager_1.GlobalUtils.curDir });
                c.on('message', msg => {
                    this.logger.trace(msg);
                });
                c.on('close', (code, signal) => {
                    if (signal)
                        return reject(new Error(`Error code ${code}, signal: ${signal}`));
                    resolve({ code, signal });
                });
                c.on('error', reject);
            });
            return rs;
        }
        finally {
            this.logger.debugBlock(false);
        }
    }
    async dispose() { }
}
exports.default = Exec;
//# sourceMappingURL=exec.js.map