"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const variables_manager_1 = require("../../managers/variables-manager");
const testing_1 = require("../../testing");
const js_1 = __importDefault(require("./js"));
let jsExec;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    jsExec = testing_1.ElementTest.create(js_1.default);
});
afterAll(async () => {
    await jsExec.dispose();
});
test('should be executed', async () => {
    const txt = 'hello world';
    await jsExec.init({
        title: 'Test function',
        script: `return '${txt}'`
    });
    const msg = await jsExec.exec();
    expect(msg).toBe(txt);
});
test('should get value directly from global vars', async () => {
    variables_manager_1.GlobalVars.txt = 'hello world';
    await jsExec.init(`logger.info('Test here'); return vars.txt`);
    const msg = await jsExec.exec();
    expect(msg).toBe(variables_manager_1.GlobalVars.txt);
});
test('should not get expression value from global vars', async () => {
    variables_manager_1.GlobalVars.txt = 'hello world';
    await jsExec.init(`return "\${vars.txt}"`);
    const msg = await jsExec.exec();
    expect(msg).toBe('${vars.txt}');
});
//# sourceMappingURL=js.spec.js.map