"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const format_1 = require("../../libs/format");
const variables_manager_1 = require("../../managers/variables-manager");
const testing_1 = require("../../testing");
const sh_1 = __importDefault(require("./sh"));
let shExec;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    shExec = testing_1.ElementTest.create(sh_1.default);
});
afterAll(async () => {
    await shExec.dispose();
});
test('should create a new file', async () => {
    const path = `/tmp/${(0, format_1.formatFileName)('No Say Ben( Remix ) | Cover Bố Mẹ Gấu | VanhLeg')}.mp3`;
    try {
        await shExec.init({
            title: 'Test function',
            script: `touch "${path}"`
        });
        await shExec.exec();
        expect((0, fs_1.existsSync)(path)).toBe(true);
    }
    finally {
        (0, fs_1.existsSync)(path) && (0, fs_1.unlinkSync)(path);
    }
});
test('should be executed', async () => {
    const txt = 'hello world';
    await shExec.init({
        title: 'Test function',
        script: `echo "${txt}"`
    });
    const msg = await shExec.exec();
    expect(msg).toBe(txt);
});
test('should get expression value from global vars', async () => {
    variables_manager_1.GlobalVars.txt = 'hello world';
    await shExec.init(`echo "\${vars.txt}"`);
    const msg = await shExec.exec();
    expect(msg).toBe(variables_manager_1.GlobalVars.txt);
});
//# sourceMappingURL=sh.spec.js.map