"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const yaml_1 = require("yaml");
const variables_manager_1 = require("../../managers/variables-manager");
const read_1 = __importDefault(require("./read"));
let reader;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    reader = testing_1.ElementTest.create(read_1.default);
});
afterEach(async () => {
    await reader.dispose();
});
test('Read text file', async () => {
    const tmp = new testing_1.TmpFile();
    await tmp.create('Hello world');
    try {
        await reader.init({
            path: tmp.file,
            vars: {
                msg: '${this.data}'
            }
        });
        await reader.exec();
        expect(variables_manager_1.GlobalVars.msg).toBe('Hello world');
    }
    finally {
        tmp.remove();
    }
});
test('Read json file', async () => {
    const tmp = new testing_1.TmpFile();
    await tmp.create(JSON.stringify({ msg: 'Hello world' }));
    try {
        await reader.init({
            path: tmp.file,
            format: 'json',
            vars: {
                msg: '${this.data.msg}'
            }
        });
        await reader.exec();
        expect(variables_manager_1.GlobalVars.msg).toBe('Hello world');
    }
    finally {
        tmp.remove();
    }
});
test('Read yaml file', async () => {
    const tmp = new testing_1.TmpFile();
    await tmp.create((0, yaml_1.stringify)({ msg: 'Hello world' }));
    try {
        await reader.init({
            path: tmp.file,
            format: 'yaml',
            vars: 'data'
        });
        await reader.exec();
        expect(variables_manager_1.GlobalVars.data.msg).toBe('Hello world');
    }
    finally {
        tmp.remove();
    }
});
//# sourceMappingURL=read.spec.js.map