"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const os_1 = require("os");
const path_1 = require("path");
const testing_1 = require("../../testing");
const yaml_1 = require("yaml");
const write_1 = __importDefault(require("./write"));
let writer;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    writer = testing_1.ElementTest.create(write_1.default);
});
afterEach(async () => {
    await writer.dispose();
});
test('Write text file', async () => {
    const p = (0, path_1.join)((0, os_1.tmpdir)(), Math.random().toString());
    try {
        await writer.init({
            path: p,
            content: 'Hello world'
        });
        await writer.exec();
        expect((0, fs_1.existsSync)(p)).toBe(true);
        const msg = (0, fs_1.readFileSync)(p).toString('utf-8');
        expect(msg).toBe('Hello world');
    }
    finally {
        (0, fs_1.unlinkSync)(p);
    }
});
test('Write json file', async () => {
    const p = (0, path_1.join)((0, os_1.tmpdir)(), Math.random().toString());
    try {
        await writer.init({
            path: p,
            format: 'json',
            content: {
                msg: 'Hello world'
            }
        });
        await writer.exec();
        expect((0, fs_1.existsSync)(p)).toBe(true);
        const obj = JSON.parse((0, fs_1.readFileSync)(p).toString('utf-8'));
        expect(obj.msg).toBe('Hello world');
    }
    finally {
        (0, fs_1.unlinkSync)(p);
    }
});
test('Write json file with pretty mode', async () => {
    const p = (0, path_1.join)((0, os_1.tmpdir)(), Math.random().toString());
    try {
        await writer.init({
            path: p,
            format: 'json',
            pretty: true,
            content: {
                msg: 'Hello world'
            }
        });
        await writer.exec();
        expect((0, fs_1.existsSync)(p)).toBe(true);
        const msg = (0, fs_1.readFileSync)(p).toString('utf-8');
        expect(msg).toBe('{\n  "msg": "Hello world"\n}');
    }
    finally {
        (0, fs_1.unlinkSync)(p);
    }
});
test('Write yaml file', async () => {
    const p = (0, path_1.join)((0, os_1.tmpdir)(), Math.random().toString());
    try {
        await writer.init({
            path: p,
            format: 'yaml',
            content: {
                msg: 'Hello world'
            }
        });
        await writer.exec();
        expect((0, fs_1.existsSync)(p)).toBe(true);
        const obj = (0, yaml_1.parse)((0, fs_1.readFileSync)(p).toString('utf-8'));
        expect(obj.msg).toBe('Hello world');
    }
    finally {
        (0, fs_1.unlinkSync)(p);
    }
});
//# sourceMappingURL=write.spec.js.map