"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = __importDefault(require("events"));
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const element_utils_1 = require("../element.utils");
class Group extends events_1.default {
    title;
    parent;
    ignoreVarsBeforeExec = ['runs', 'count', 'asyncJobs'];
    count = 0;
    runs;
    logger;
    asyncJobs;
    async init(props) {
        if (Array.isArray(props)) {
            this.runs = props;
        }
        else {
            Object.assign(this, props);
        }
        this.runs = this.runs?.filter(e => e) || [];
        this.asyncJobs = [];
    }
    async exec(input) {
        const runs = new Array();
        for (const _e of this.runs) {
            const e = typeof _e === 'string' ? { 'echo': { content: _e } } : _e;
            const name = Object.keys(e)[0];
            const props = (0, lodash_clonedeep_1.default)(e[name]);
            const ElemClass = await (0, element_utils_1.loadElementClass)(name, this.logger);
            const elem = (0, element_utils_1.createElement)(ElemClass);
            elem.tag = name;
            elem.parent = this;
            elem.logger = this.logger.clone(elem.tag);
            this.emit('item/created', elem, props);
            await elem.init(props);
            if (elem.ignore)
                continue;
            const loop = elem.loop;
            if (loop === undefined) {
                runs.push(elem);
                if (this.asyncJobs.length && !elem.async) {
                    await Promise.all(this.asyncJobs);
                    this.asyncJobs.splice(0, this.asyncJobs.length);
                }
                await this.execElement(elem, input);
            }
            else {
                let loopCondition = await (0, element_utils_1.getElementLoop)(loop);
                if (loopCondition) {
                    if (Array.isArray(loopCondition)) {
                        for (let i = 0; i < loopCondition.length; i++) {
                            const newElem = await elem['$$clone'](this);
                            newElem.loopKey = i;
                            newElem.loopValue = loopCondition[i];
                            runs.push(newElem);
                            await this.execElement(newElem, input);
                        }
                    }
                    else if (typeof loopCondition === 'object') {
                        for (let key in loopCondition) {
                            const newElem = await elem['$$clone'](this);
                            newElem.loopKey = key;
                            newElem.loopValue = loopCondition[key];
                            runs.push(newElem);
                            await this.execElement(newElem, input);
                        }
                    }
                    else if (loopCondition === true) {
                        while (loopCondition) {
                            const newElem = await elem['$$clone'](this);
                            newElem.loopValue = loopCondition;
                            runs.push(newElem);
                            await this.execElement(newElem, input);
                            loopCondition = await (0, element_utils_1.getElementLoop)(loop);
                        }
                    }
                }
            }
        }
        if (this.asyncJobs.length) {
            await Promise.all(this.asyncJobs);
            this.asyncJobs.splice(0, this.asyncJobs.length);
        }
        return runs;
    }
    async dispose() { }
    async execElement(elem, input) {
        const isContinue = await elem['$$prepare']();
        if (!isContinue)
            return;
        this.count++;
        const p = new Promise(async (resolve, reject) => {
            let error;
            try {
                await elem.exec(input);
            }
            catch (err) {
                reject(err);
            }
            finally {
                if (elem instanceof Group)
                    this.count += elem.count;
                await elem.dispose();
            }
            resolve(error);
        });
        if (!elem.async) {
            await p;
        }
        else {
            this.asyncJobs.push(p);
        }
    }
}
exports.default = Group;
//# sourceMappingURL=group.js.map