"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const variables_manager_1 = require("../../managers/variables-manager");
const testing_1 = require("../../testing");
const _1 = __importDefault(require("."));
let group;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    group = testing_1.ElementTest.create(_1.default);
});
afterEach(async () => {
    await group.dispose();
});
test('if - condition', async () => {
    let echo;
    group.on('item/created', (item, props) => {
        if (props.id !== 'echo')
            return;
        echo = item;
        echo.exec = jest.fn();
    });
    await group.init([
        {
            echo: {
                id: 'echo',
                loop: '${[1,2,3]}',
                if: '${this.loopValue %2 === 0}',
                content: '${this.loopValue}',
            }
        }
    ]);
    await group.exec();
    expect(echo.exec).toBeCalledTimes(1);
});
test('loop', async () => {
    let echo;
    group.on('item/created', (item) => {
        echo = item;
        echo.exec = jest.fn();
    });
    await group.init([
        {
            echo: {
                loop: '${[1,2,3]}',
                content: '${this.loopValue}',
            }
        }
    ]);
    await group.exec();
    expect(echo.exec).toBeCalledTimes(3);
});
test('pass a config into item in group', async () => {
    await group.init([
        {
            "exec'js": {
                script: 'return "OK"',
                vars: 'result'
            }
        }
    ]);
    await group.exec();
    expect(group.count).toBe(1);
    expect(variables_manager_1.GlobalVars.result).toBe('OK');
});
test('pass full group information', async () => {
    await group.init({
        title: 'Test group',
        runs: [
            {
                "exec'js": {
                    script: 'return "OK"',
                    vars: 'result'
                }
            }
        ]
    });
    await group.exec();
    expect(group.count).toBe(1);
    expect(variables_manager_1.GlobalVars.result).toBe('OK');
});
test('run with false condition', async () => {
    await group.init({
        title: 'Test group',
        runs: [
            {
                "exec'js": {
                    if: '${false}',
                    script: 'return "OK"',
                    vars: 'result'
                }
            }
        ]
    });
    await group.exec();
    expect(group.count).toBe(0);
    expect(variables_manager_1.GlobalVars.result).toBeUndefined();
});
//# sourceMappingURL=group.spec.js.map