"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jest_mock_server_1 = require("jest-mock-server");
const variables_manager_1 = require("../../managers/variables-manager");
const testing_1 = require("../../testing");
const del_1 = require("./del");
const server = new jest_mock_server_1.MockServer();
let request;
beforeAll(() => server.start());
afterAll(() => server.stop());
beforeEach(() => {
    (0, testing_1.cleanTest)();
    request = testing_1.ElementTest.create(del_1.Del);
    server.reset();
});
afterEach(async () => {
    await request.dispose();
});
test('should send request ok', async () => {
    server.delete('/')
        .mockImplementationOnce((ctx) => {
        ctx.status = 201;
        ctx.message = 'OK MEN';
        expect(ctx.query.time).toBeDefined();
        expect(ctx.query.rd).toBeDefined();
    });
    await request.init({
        url: server.getURL().toString() + '?time=' + Date.now(),
        query: {
            rd: Math.random().toString()
        },
        vars: {
            status: '${this.response.status}',
            statusText: '${this.response.statusText}'
        }
    });
    await request.exec();
    expect(variables_manager_1.GlobalVars.status).toBe(201);
    expect(variables_manager_1.GlobalVars.statusText).toBe('OK MEN');
});
//# sourceMappingURL=del.spec.js.map