"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jest_mock_server_1 = require("jest-mock-server");
const variables_manager_1 = require("../../managers/variables-manager");
const testing_1 = require("../../testing");
const head_1 = require("./head");
const server = new jest_mock_server_1.MockServer();
let request;
beforeAll(() => server.start());
afterAll(() => server.stop());
beforeEach(() => {
    (0, testing_1.cleanTest)();
    request = testing_1.ElementTest.create(head_1.Head);
    server.reset();
});
afterEach(async () => {
    await request.dispose();
});
test('should send request ok', async () => {
    server.head('/')
        .mockImplementationOnce((ctx) => {
        ctx.status = 201;
        ctx.message = 'OK MEN';
        expect(ctx.query.time).toBeDefined();
        expect(ctx.query.rd).toBeDefined();
    });
    await request.init({
        url: server.getURL().toString() + '?time=' + Date.now(),
        query: {
            rd: Math.random().toString()
        },
        vars: {
            status: '${this.response.status}',
            statusText: '${this.response.statusText}'
        }
    });
    await request.exec();
    expect(request.error).toBeUndefined();
    expect(variables_manager_1.GlobalVars.status).toBe(201);
    expect(variables_manager_1.GlobalVars.statusText).toBe('OK MEN');
});
test('should send request error', async () => {
    server.head('/')
        .mockImplementationOnce((ctx) => {
        ctx.status = 404;
        ctx.message = 'NOT FOUND';
        expect(ctx.query.time).toBeDefined();
    });
    await request.init({
        url: server.getURL().toString() + "?time=" + Date.now(),
    });
    await request.exec();
    expect(request.error).toBeDefined();
    expect(request.response.status).toBe(404);
    expect(request.response.statusText).toBe('NOT FOUND');
});
test('should error before send request', async () => {
    server.head('/')
        .mockImplementationOnce((ctx) => {
        ctx.status = 201;
        ctx.message = 'OK MEN';
        expect(ctx.query.rd).toBeDefined();
    });
    await request.init({
        url: 'http://localhost',
        query: {
            rd: Math.random().toString()
        }
    });
    try {
        await request.exec();
    }
    catch (err) {
        expect(err).toBeDefined();
        expect(request.response).toBeUndefined();
    }
});
//# sourceMappingURL=head.spec.js.map