"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Sub = void 0;
const http_1 = require("http");
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const querystring_1 = require("querystring");
const element_utils_1 = require("../../../components/element.utils");
const group_1 = __importDefault(require("../../../components/group"));
const queue_runner_1 = require("../../../libs/queue/queue-runner");
const variables_manager_1 = require("../../../managers/variables-manager");
class Sub extends group_1.default {
    inputExecName = '';
    address = '0.0.0.0:3000';
    queue;
    queueRunner;
    server;
    constructor() {
        super();
        this.ignoreVarsBeforeExec.push('server', 'queueRunner');
    }
    async handleQueue(request) {
        await (0, element_utils_1.setVarsAfterExec)(this, this.logger);
        await super.exec(request);
    }
    async init(props) {
        await super.init(props);
        Object.assign(this, props);
    }
    async exec() {
        if (this.queue?.file) {
            this.queueRunner = new queue_runner_1.QueueRunner('http/jobs', this.logger, this, variables_manager_1.GlobalUtils.getPath(this.queue.file));
        }
        this.server = (0, http_1.createServer)((req, res) => this.handleRequest(req, res));
        await new Promise((resolve, reject) => {
            this.server.on('error', reject);
            this.server.on('close', resolve);
            const [host, port] = this.address.trim().split(':');
            this.server.listen(+port, host, () => {
                this.logger.debug('http/jobs listened at %s', this.address);
                this.queueRunner?.start();
            });
        });
        this.server = null;
        return [];
    }
    async exit() {
        if (!this.server?.listening)
            return;
        this.server.close();
        await this.queueRunner?.stop();
    }
    async dispose() {
        await this.exit();
    }
    getRequestBody(req) {
        return new Promise((resolve, reject) => {
            const chunks = [];
            req.on("data", (chunk) => chunks.push(chunk));
            req.on('error', reject);
            req.on("end", () => {
                const data = Buffer.concat(chunks).toString();
                resolve(data ? JSON.parse(data) : data);
            });
        });
    }
    async handleRequest(req, res) {
        this.logger.debug(`%s %s \t%s`, '⥃', req.method, req.url);
        try {
            let data = {};
            const qstr = req.url.split('?')[1];
            if (qstr) {
                data = (0, querystring_1.parse)(qstr);
            }
            const requestBody = await this.getRequestBody(req);
            if (requestBody) {
                (0, lodash_merge_1.default)(data, requestBody);
            }
            if (this.queueRunner) {
                this.queueRunner?.push(data);
            }
            else {
                await this.handleQueue(data);
            }
        }
        finally {
            res.statusCode = 201;
            res.end();
        }
    }
}
exports.Sub = Sub;
//# sourceMappingURL=sub.js.map