"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputAbstract = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const process_1 = require("process");
const prompts_1 = __importDefault(require("prompts"));
const figures_1 = __importDefault(require("prompts/lib/util/figures"));
const style_1 = __importDefault(require("prompts/lib/util/style"));
const symbols = Object.freeze({
    aborted: ansi_colors_1.default.red((globalThis.inputIndent || '') + figures_1.default.cross),
    done: ansi_colors_1.default.green((globalThis.inputIndent || '') + figures_1.default.tick),
    exited: ansi_colors_1.default.yellow((globalThis.inputIndent || '') + figures_1.default.cross),
    default: ansi_colors_1.default.cyan((globalThis.inputIndent || '') + '?')
});
style_1.default.symbol = (done, aborted, exited) => {
    return aborted ? symbols.aborted : exited ? symbols.exited : done ? symbols.done : symbols.default;
};
class InputAbstract {
    type;
    label;
    default;
    required;
    question;
    constructor(props) {
        Object.assign(this, props);
    }
    async exec(opts) {
        const { type, default: initial, label: message, question, ...moreOpts } = this;
        this.question = await (0, prompts_1.default)({
            type,
            name: 'value',
            initial,
            message,
            ...moreOpts,
            ...opts
        });
        return this.question.value;
    }
    answer(value) {
        if (value) {
            let keys = [];
            if (Array.isArray(value)) {
                keys = value;
            }
            else {
                keys = value.toString().split('').map(k => {
                    return { key: k, name: k };
                });
            }
            keys.forEach(({ key, name }) => {
                process_1.stdin.emit('keypress', key, { name });
            });
        }
        process_1.stdin.emit('keypress', '\r', {
            name: 'return'
        });
    }
}
exports.InputAbstract = InputAbstract;
//# sourceMappingURL=input.abstract.js.map