"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const variables_manager_1 = require("../../managers/variables-manager");
const test_error_1 = require("./test-error");
class Test {
    defaultTestTitle;
    testTitle;
    check;
    script;
    setContextVarsString;
    vars;
    error;
    ignoreVarsBeforeExec = ['script', 'defaultTestTitle'];
    logger;
    async init(props) {
        if (typeof props === 'string') {
            this.check = props;
            this.defaultTestTitle = this.check || this.script;
        }
        else {
            const { title, ...eprops } = props;
            Object.assign(this, eprops);
            this.testTitle = title;
            if (!this.testTitle)
                this.defaultTestTitle = this.check || this.script;
        }
    }
    failed(description = '') {
        this.error = new test_error_1.TestError(description);
        throw this.error;
    }
    async exec() {
        try {
            if (this.check !== undefined) {
                const rs = this.check;
                this.setContextVarsString = !!rs;
                if (!rs)
                    this.failed();
            }
            if (this.script) {
                const func = new Function(`const [vars, utils, logger] = arguments; ${this.script}`);
                try {
                    await func.call(this, variables_manager_1.GlobalVars, variables_manager_1.GlobalUtils, this.logger);
                }
                catch (err) {
                    this.failed(err.message);
                }
            }
            this.testTitle && this.logger.info(this.testTitle);
        }
        catch (err) {
            if (err !== this.error)
                throw err;
            this.logger.error(`%s\t%s`, this.testTitle || this.defaultTestTitle, ansi_colors_1.default.italic.gray(this.error.message));
        }
        finally {
            this.setContextVarsString = !this.error;
        }
        return this.setContextVarsString;
    }
    async dispose() { }
}
exports.default = Test;
//# sourceMappingURL=test.js.map