"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const variables_manager_1 = require("../../managers/variables-manager");
const testing_1 = require("../../testing");
const _1 = __importDefault(require("."));
let testElem;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    testElem = testing_1.ElementTest.create(_1.default);
});
afterEach(async () => {
    await testElem.dispose();
});
test('quick test without title', async () => {
    variables_manager_1.GlobalVars.i = 11;
    await testElem.init('${vars.i >= 10}');
    const rs = await testElem.exec();
    expect(rs).toBe(true);
});
test('test script without title', async () => {
    variables_manager_1.GlobalVars.i = 9;
    await testElem.init({
        check: '${vars.i >= 10}'
    });
    const rs = await testElem.exec();
    expect(rs).toBe(false);
    expect(testElem.error.message).toBe('');
});
test('quick test', async () => {
    variables_manager_1.GlobalVars.i = 11;
    await testElem.init({
        title: 'Greater than 10',
        check: '${vars.i >= 10}'
    });
    const rs = await testElem.exec();
    expect(rs).toBe(true);
});
test('test with a script', async () => {
    variables_manager_1.GlobalVars.i = 11;
    await testElem.init({
        title: 'Greater than 10',
        script: "vars.i >= 10"
    });
    const rs = await testElem.exec();
    expect(rs).toBe(true);
});
test('quick test failed', async () => {
    variables_manager_1.GlobalVars.i = 9;
    await testElem.init({
        title: 'Greater than 10',
        check: '${vars.i >= 10}'
    });
    const rs = await testElem.exec();
    expect(rs).toBe(false);
    expect(testElem.error.message).toBe('');
});
test('test with a script failed then print error detail', async () => {
    variables_manager_1.GlobalVars.i = 9;
    const mes = 'i is less than 10';
    await testElem.init({
        title: 'Greater than 10',
        script: `if (vars.i < 10) this.failed('${mes}')`
    });
    const rs = await testElem.exec();
    expect(rs).toBe(false);
    expect(testElem.error.message).toBe(mes);
});
//# sourceMappingURL=test.spec.js.map