"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const _1 = __importDefault(require("."));
const variables_manager_1 = require("../../managers/variables-manager");
let vars;
beforeEach(() => {
    (0, testing_1.cleanTest)();
    vars = testing_1.ElementTest.create(_1.default);
});
afterEach(async () => {
    await vars.dispose();
});
test('should set to global vars', async () => {
    try {
        await vars.init({
            string: 'foo',
            number: 1,
            boolean: true,
            object: {
                string: 'foo',
                number: 1,
                boolean: true,
            },
            array1: [1, '2', true],
            array2: [{
                    string: 'foo',
                    number: 1,
                    boolean: true,
                }]
        });
        expect(variables_manager_1.GlobalVars.string).toBeUndefined();
        expect(variables_manager_1.GlobalVars.number).toBeUndefined();
        expect(variables_manager_1.GlobalVars.boolean).toBeUndefined();
        expect(variables_manager_1.GlobalVars.object).toBeUndefined();
        expect(variables_manager_1.GlobalVars.array1).toBeUndefined();
        expect(variables_manager_1.GlobalVars.array2).toBeUndefined();
        await vars.exec();
        expect(variables_manager_1.GlobalVars.string).toBe('foo');
        expect(variables_manager_1.GlobalVars.number).toBe(1);
        expect(variables_manager_1.GlobalVars.boolean).toBe(true);
        expect(variables_manager_1.GlobalVars.object).toStrictEqual({
            string: 'foo',
            number: 1,
            boolean: true,
        });
        expect(variables_manager_1.GlobalVars.array1).toStrictEqual([1, '2', true]);
        expect(variables_manager_1.GlobalVars.array2).toStrictEqual([{
                string: 'foo',
                number: 1,
                boolean: true,
            }]);
    }
    finally {
        await vars.dispose();
    }
});
test('should eval value into vars', async () => {
    await vars.init({
        name: 'thanh'
    });
    await vars.exec();
    const test = testing_1.ElementTest.create(_1.default);
    await test.init({
        hello: 'hello ${vars.name}'
    });
    await test.exec();
    await test.dispose();
    expect(variables_manager_1.GlobalVars.hello).toBe('hello thanh');
});
//# sourceMappingURL=vars.spec.js.map