"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("./managers/modules-manager");
const modules_manager_1 = require("./managers/modules-manager");
const summary_1 = require("./analystic/summary");
const logger_1 = require("./libs/logger");
const scenes_manager_1 = require("./managers/scenes-manager");
const variables_manager_1 = require("./managers/variables-manager");
(0, variables_manager_1.resetGlobalVars)();
(0, modules_manager_1.registerModulePlatform)();
(async () => {
    try {
        await fetch('http://127.0.0.1');
    }
    catch { }
    finally {
        console.clear();
    }
    const logger = new logger_1.Logger(logger_1.LoggerLevel.ALL);
    const summary = new summary_1.Summary(logger);
    const sceneManager = new scenes_manager_1.ScenesManager(logger);
    new Array('SIGINT', 'SIGTERM', 'SIGQUIT')
        .forEach(signal => process.on(signal, async () => {
        await sceneManager.dispose();
        process.exit(0);
    }));
    try {
        await summary.start();
        const file = process.argv[2];
        if (!file)
            return summary.help();
        const decryptedPassword = process.argv[3];
        await sceneManager.init({ path: file, password: decryptedPassword });
        await sceneManager.exec();
    }
    catch (err) {
        logger.fatal(err);
        throw err;
    }
    finally {
        await sceneManager.dispose();
        await summary.stop();
        summary.print();
    }
})();
//# sourceMappingURL=index.js.map