"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Env = void 0;
const fs_1 = require("fs");
const lodash_merge_1 = __importDefault(require("lodash.merge"));
class Env {
    logger;
    constructor(logger) {
        this.logger = logger;
    }
    async loadEnvToBase(baseConfig, ...envFiles) {
        const config = {};
        for (const file of envFiles.filter(e => e)) {
            if (typeof file === 'string') {
                const env = {};
                try {
                    if (file && (0, fs_1.statSync)(file)) {
                        const content = (0, fs_1.readFileSync)(file).toString('utf8');
                        content.split('\n')
                            .map(e => e.trim())
                            .filter(e => e && !e.startsWith('#'))
                            .forEach(e => {
                            const [key, vl] = this.parseEnvLine(e);
                            env[key.trim().toUpperCase()] = vl.trim();
                        });
                    }
                }
                catch (err) {
                    this.logger.warn(`Could not found config file at ${file}`);
                }
                (0, lodash_merge_1.default)(config, env);
            }
            else {
                (0, lodash_merge_1.default)(config, Object.keys(file)
                    .reduce((sum, e) => {
                    sum[e.toUpperCase()] = file[e];
                    return sum;
                }, {}));
            }
        }
        this.castToObject(baseConfig, config);
        return baseConfig;
    }
    castToObject(obj, pro, prefix = '') {
        for (let k in obj) {
            if (typeof obj[k] === 'function')
                continue;
            if (typeof obj[k] === 'object') {
                obj[k] = this.castToObject(obj[k], pro, (prefix + k + '_').toUpperCase());
            }
            else if (Array.isArray(obj[k])) {
                for (let i in obj[k]) {
                    obj[k][i] = this.castToObject(obj[k][i], pro, (prefix + k + '_' + i + '_').toUpperCase());
                }
            }
            else {
                let lk = prefix + k.toUpperCase().replace('.', '_');
                if (pro[lk] !== undefined && obj[k] !== undefined) {
                    if (typeof obj[k] === 'boolean') {
                        switch (pro[lk]) {
                            case 'true':
                                obj[k] = true;
                                break;
                            case '1':
                                obj[k] = true;
                                break;
                            case 'yes':
                                obj[k] = true;
                                break;
                            case 'false':
                                obj[k] = false;
                                break;
                            case '0':
                                obj[k] = false;
                                break;
                            case 'no':
                                obj[k] = false;
                                break;
                            default:
                                obj[k] = new Boolean(pro[lk]).valueOf();
                                break;
                        }
                    }
                    else if (typeof obj[k] === 'number') {
                        obj[k] = +pro[lk];
                    }
                    else {
                        obj[k] = pro[lk];
                    }
                }
            }
        }
        return obj;
    }
    parseEnvLine(urlStr) {
        const idx = urlStr.indexOf('=');
        if (idx === -1)
            return [urlStr, ''];
        const first = urlStr.substring(0, idx);
        const second = urlStr.substring(idx + 1);
        return [first, second];
    }
}
exports.Env = Env;
//# sourceMappingURL=env.js.map