"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatFileName = exports.undefinedToNull = exports.formatDuration = exports.formatNumber = void 0;
function formatNumber(n, opts) {
    return new Number(n).toLocaleString(undefined, opts);
}
exports.formatNumber = formatNumber;
function formatDuration(ms) {
    function getNum(ms, max) {
        if (ms < max)
            return [0, ms];
        const n = Math.floor(ms / max);
        return [n, ms - (n * max)];
    }
    const [h, remainH] = getNum(ms, 1000 * 60 * 60);
    const [m, remainM] = getNum(remainH, 1000 * 60);
    const [s, ss] = getNum(remainM, 1000);
    const time = [ss, s, m, h].filter(n => n);
    const label = ['ms', 's', 'm', 'h'];
    return time.map((t, i) => `${t}${label[i]}`).reverse().join(' ');
}
exports.formatDuration = formatDuration;
function undefinedToNull(vl) {
    return vl !== undefined ? vl : null;
}
exports.undefinedToNull = undefinedToNull;
const accentsMap = {
    a: /[àảãáạăằẳẵắặâầẩẫấậ]/g,
    A: /[ÀẢÃÁẠĂẰẲẴẮẶÂẦẨẪẤẬ]/g,
    d: /[đ]/g,
    D: /[Đ]/g,
    e: /[èẻẽéẹêềểễếệ]/g,
    E: /[ÈẺẼÉẸÊỀỂỄẾỆ]/g,
    i: /[ìỉĩíị]/g,
    I: /[ÌỈĨÍỊ]/g,
    o: /[òỏõóọôồổỗốộơờởỡớợ]/g,
    O: /[ÒỎÕÓỌÔỒỔỖỐỘƠỜỞỠỚỢ]/g,
    u: /[ùủũúụưừửữứự]/g,
    U: /[ÙỦŨÚỤƯỪỬỮỨỰ]/g,
    y: /[ỳỷỹýỵ]/g,
    Y: /[ỲỶỸÝỴ]/g
};
function formatFileName(name, char = ' ') {
    if (!name)
        throw new Error(`File name is required before want to format`);
    Object.keys(accentsMap)
        .forEach(uc => {
        name = name.replace(accentsMap[uc], uc);
    });
    return name.split('.').map(name => name.replace(/[^a-zA-Z0-9_\-]+/g, char).replace(/\s\s+/g, char).trim()).join('.');
}
exports.formatFileName = formatFileName;
//# sourceMappingURL=format.js.map