"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueueRunner = void 0;
const time_1 = require("../time");
const queue_file_1 = require("./queue-file");
class QueueRunner {
    name;
    queueRunnerHandler;
    queueData = new Array();
    isRunning = false;
    delayTime = 500;
    db;
    logger;
    constructor(name, logger, queueRunnerHandler, queueFile) {
        this.name = name;
        this.queueRunnerHandler = queueRunnerHandler;
        this.logger = logger.clone(QueueRunner.name);
        if (queueFile)
            this.db = new queue_file_1.QueueFile(queueFile, this.logger);
    }
    push(input) {
        this.logger.debug(`Added \t%s`, `[${this.name}]`);
        this.queueData.push(input);
        this.db?.save(this.queueData);
    }
    async exec() {
        while (this.isRunning) {
            let input;
            while ((input = this.queueData[0]) && this.isRunning) {
                this.logger.debug(`Pulled \t%s`, `[${this.name}]`);
                await this.queueRunnerHandler.handleQueue(input);
                this.db?.save(this.queueData);
                this.queueData.shift();
            }
            await (0, time_1.sleep)(this.delayTime);
        }
    }
    async stop() {
        if (this.isRunning) {
            this.isRunning = false;
            await (0, time_1.sleep)(this.delayTime);
        }
    }
    async start() {
        this.logger.debug(`Start  \t%s`, this.name);
        this.isRunning = true;
        this.queueData = this.db?.load() || [];
        await this.exec();
    }
}
exports.QueueRunner = QueueRunner;
//# sourceMappingURL=queue-runner.js.map