"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PackagesManager = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const child_process_1 = require("child_process");
const path_1 = require("path");
const progress_bar_1 = require("./../libs/progress-bar");
const modules_manager_1 = require("./modules-manager");
class PackagesManager {
    logger;
    bin;
    get cmdInstall() {
        return this.bin === 'npm' ? `npm install --no-package-lock --save-optional --prefix ${modules_manager_1.nodeModulesDir}` : `yarn add --no-lockfile --optional --modules-folder ${(0, path_1.join)(modules_manager_1.nodeModulesDir, 'node_modules')}`;
    }
    constructor(logger) {
        this.logger = logger;
        let log = (0, child_process_1.execSync)('yarn -v').toString();
        if (!log) {
            log = (0, child_process_1.execSync)('npm -v').toString();
            if (!log)
                throw new Error('Not installed npm or yarn yet');
            this.bin = 'npm';
        }
        else {
            this.bin = 'yarn';
        }
    }
    async install(...packages) {
        const cmd = `${this.cmdInstall} ${packages.map(p => `"${p}"`).join(' ')}`;
        this.logger.debug(`> %s`, cmd);
        const msg = `tags ${packages.map(e => `"${e}"`).join(', ')}`;
        const bar = new progress_bar_1.ProgressBar(this.logger);
        try {
            await bar.init(`Installing ${msg}`);
            bar.start();
            const { stdout, stderr } = await new Promise((resolve, reject) => {
                (0, child_process_1.exec)(cmd, (err, stdout, stderr) => {
                    if (err)
                        return reject(err);
                    resolve({ stdout, stderr });
                });
            });
            bar.passed(`Installed ${msg} successfully`);
            this.logger.debugBlock(true);
            if (stdout)
                this.logger.debug(stdout);
            if (stderr)
                this.logger.debug(ansi_colors_1.default.yellow(stderr));
            this.logger.debugBlock(false);
        }
        catch (err) {
            bar.failed(`Installed ${msg} failed`);
            this.logger.error(err.message);
        }
    }
}
exports.PackagesManager = PackagesManager;
//# sourceMappingURL=packages-manager.js.map