"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScenesManager = void 0;
const element_utils_1 = require("./../components/element.utils");
const scene_1 = __importDefault(require("./../components/scene"));
const events_manager_1 = require("./../managers/events-manager");
class ScenesManager {
    #scene;
    get count() {
        return this.#scene.count;
    }
    get encryptedPath() {
        return this.#scene.encryptedPath;
    }
    get path() {
        return this.#scene.path;
    }
    constructor(logger) {
        this.#scene = (0, element_utils_1.createElement)(scene_1.default, true);
        this.#scene.logger = logger.clone('scene');
    }
    async exec() {
        events_manager_1.globalEvent.emit('scene/exec:before');
        try {
            const rs = await this.#scene.exec();
            return rs;
        }
        finally {
            events_manager_1.globalEvent.emit('scene/exec:end');
        }
    }
    async dispose() {
        events_manager_1.globalEvent.emit('scene/dispose:before');
        try {
            const rs = await this.#scene.dispose();
            return rs;
        }
        finally {
            events_manager_1.globalEvent.emit('scene/dispose:end');
        }
    }
    async init(props) {
        events_manager_1.globalEvent.emit('scene/init:before');
        try {
            await this.#scene.init({ path: props.path, content: props.content, password: props.password });
        }
        finally {
            events_manager_1.globalEvent.emit('scene/init:end');
        }
    }
}
exports.ScenesManager = ScenesManager;
//# sourceMappingURL=scenes-manager.js.map