"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGetEvalExp = exports.getVars = exports.setVars = exports.resetGlobalVars = exports.GlobalUtils = exports.GlobalVars = void 0;
const path_1 = __importDefault(require("path"));
exports.GlobalVars = {};
exports.GlobalUtils = {
    get base64() {
        const { Base64 } = require('../libs/encrypt/base64');
        return new Base64();
    },
    get md5() {
        const { MD5 } = require('../libs/encrypt/md5');
        return new MD5();
    },
    get aes() {
        const { AES } = require('../libs/encrypt/aes');
        return new AES();
    },
    format: {
        fileName(fileName) {
            const { formatFileName } = require('../libs/format');
            return formatFileName(fileName);
        },
        number(num, opts) {
            const { formatNumber } = require('../libs/format');
            return formatNumber(num, opts);
        }
    },
    rootDir: '',
    curDir: '',
    getPath(p) {
        if (!p)
            return p;
        if (path_1.default.isAbsolute(p))
            return p;
        if (p.startsWith('~/'))
            return path_1.default.join(this.rootDir, p.split('~/')[1]);
        return path_1.default.join(this.curDir, p);
    }
};
function resetGlobalVars() {
    exports.GlobalVars = {};
    exports.GlobalUtils.rootDir = exports.GlobalUtils.curDir = '';
}
exports.resetGlobalVars = resetGlobalVars;
async function setVars(varObj, vl, ctx) {
    if (!varObj)
        return;
    if (typeof varObj === 'string') {
        exports.GlobalVars[varObj] = vl;
        return [varObj];
    }
    else {
        const keys = Object.keys(varObj);
        for (const k of keys) {
            exports.GlobalVars[k] = await getVars(varObj[k], ctx);
        }
        return keys;
    }
}
exports.setVars = setVars;
async function getVars(str, ctx) {
    if (!str)
        return str;
    const evalExp = isGetEvalExp(str);
    switch (evalExp) {
        case String:
            str = `\`${str}\``;
            if (str[1] === '$' && str[str.length - 2] === '}') {
                str = str.replace(/^`\$\{([^\}]+)\}`$/, '$1');
            }
            let func = new Function(`const [vars, utils] = arguments; return ${str}`);
            const vl = await func.call(ctx, exports.GlobalVars, exports.GlobalUtils);
            if (typeof vl === 'string' && vl.indexOf('${') !== -1) {
                return getVars(vl, ctx);
            }
            return vl;
        case Object:
            const obj = await evalObject(str, ctx);
            return obj;
        default:
            return str;
    }
}
exports.getVars = getVars;
function isGetEvalExp(vl) {
    if (!vl)
        return null;
    if (typeof vl === 'string') {
        if (vl.includes('${'))
            return String;
    }
    else if (typeof vl === 'object') {
        if (isGetEvalExp(JSON.stringify(vl)))
            return Object;
    }
    return null;
}
exports.isGetEvalExp = isGetEvalExp;
async function evalObject(obj, ctx) {
    if (Array.isArray(obj)) {
        const vl = await Promise.all(obj.map(o => getVars(o, ctx)));
        return vl;
    }
    for (const k of Object.keys(obj)) {
        obj[k] = await getVars(obj[k], ctx);
    }
    return obj;
}
//# sourceMappingURL=variables-manager.js.map