"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const aes_1 = require("./../libs/encrypt/aes");
const base64_1 = require("./../libs/encrypt/base64");
const md5_1 = require("./../libs/encrypt/md5");
const variables_manager_1 = require("./../managers/variables-manager");
const testing_1 = require("./../testing");
beforeEach(() => {
    (0, testing_1.cleanTest)();
});
test('utils.getDir', () => {
    variables_manager_1.GlobalUtils.curDir = __dirname;
    variables_manager_1.GlobalUtils.rootDir = (0, path_1.join)(__dirname, '..');
    expect(variables_manager_1.GlobalUtils.getPath(__dirname)).toBe(__dirname);
    expect(variables_manager_1.GlobalUtils.getPath(__dirname)).toBe(__dirname);
});
test('set value to a variable to global', async () => {
    expect(variables_manager_1.GlobalVars.name).toBeUndefined();
    await (0, variables_manager_1.setVars)('name', 'thanh');
    expect(variables_manager_1.GlobalVars.name).toBe('thanh');
});
test('set a map value to variable to global', async () => {
    expect(variables_manager_1.GlobalVars.name).toBeUndefined();
    await (0, variables_manager_1.setVars)({
        name: '${this.name}'
    }, undefined, {
        name: 'thanh'
    });
    expect(variables_manager_1.GlobalVars.name).toBe('thanh');
});
test('get value from a variable in global without context', async () => {
    variables_manager_1.GlobalVars.name = 'thanh';
    const name = await (0, variables_manager_1.getVars)('${vars.name}');
    expect(name).toBe('thanh');
});
test('get value from a variable in global with context', async () => {
    variables_manager_1.GlobalVars.name = 'thanh';
    const ctx = {
        sex: 'male'
    };
    const name = await (0, variables_manager_1.getVars)('${vars.name}', ctx);
    const sex = await (0, variables_manager_1.getVars)('${this.sex}', ctx);
    expect(name).toBe('thanh');
    expect(sex).toBe('male');
});
test('get value from a value which ref to another', async () => {
    variables_manager_1.GlobalVars.last = 'doan';
    variables_manager_1.GlobalVars.name = 'thanh ${vars.last}';
    const name = await (0, variables_manager_1.getVars)('${vars.name}');
    expect(name).toBe('thanh doan');
});
test('get map value', async () => {
    variables_manager_1.GlobalVars.hobies = ['game', 'travel'];
    variables_manager_1.GlobalVars.user = {
        name: 'thanh'
    };
    const { name, last, hobby } = await (0, variables_manager_1.getVars)({
        name: '${vars.user.name}',
        last: 'doan',
        hobby: ['bia', '${vars.hobies[1]}']
    });
    expect(name).toBe('thanh');
    expect(last).toBe('doan');
    expect(hobby).toStrictEqual(['bia', 'travel']);
});
describe("global utils", () => {
    test('base64 encrypt/decrypt', async () => {
        const raw = 'thanh';
        const enc = new base64_1.Base64().encrypt(raw);
        expect(variables_manager_1.GlobalUtils.base64.encrypt(raw)).toBe(enc);
        expect(variables_manager_1.GlobalUtils.base64.decrypt(enc)).toBe(raw);
    });
    test('md5 encrypt', async () => {
        const raw = 'thanh';
        const enc = new md5_1.MD5().encrypt(raw);
        expect(variables_manager_1.GlobalUtils.md5.encrypt(raw)).toBe(enc);
    });
    test('aes encrypt/decrypt', async () => {
        const raw = 'thanh';
        const salt = 'my salt';
        const enc = new aes_1.AES().encrypt(raw, salt);
        expect(variables_manager_1.GlobalUtils.aes.encrypt(raw, salt)).not.toBe(enc);
        expect(variables_manager_1.GlobalUtils.aes.decrypt(enc, salt)).toBe(raw);
    });
});
//# sourceMappingURL=variables-manager.spec.js.map