"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElementTest = exports.cleanTest = exports.TmpFile = void 0;
const fs_1 = require("fs");
const os_1 = require("os");
const path_1 = require("path");
const element_utils_1 = require("./components/element.utils");
const tags_manager_1 = require("./managers/tags-manager");
const templates_manager_1 = require("./managers/templates-manager");
const variables_manager_1 = require("./managers/variables-manager");
const logger_1 = require("./libs/logger");
class TmpFile {
    file;
    get isExisted() {
        return (0, fs_1.existsSync)(this.file);
    }
    constructor(ext) {
        this.file = (0, path_1.join)((0, os_1.tmpdir)(), Math.random().toString());
        if (ext)
            this.file += ext;
    }
    create(content) {
        return new Promise((resolve, reject) => {
            (0, fs_1.writeFile)(this.file, content, 'utf-8', err => {
                if (err)
                    return reject(err);
                resolve(undefined);
            });
        });
    }
    remove() {
        if (this.isExisted)
            (0, fs_1.unlinkSync)(this.file);
    }
}
exports.TmpFile = TmpFile;
function cleanTest() {
    (0, variables_manager_1.resetGlobalVars)();
    tags_manager_1.tagsManager.reset();
    templates_manager_1.templatesManager.reset();
}
exports.cleanTest = cleanTest;
class ElementTest {
    static create(ElementClazz, ...args) {
        const elem = (0, element_utils_1.createElement)(ElementClazz, ...args);
        elem.logger = ElementTest.getLogger();
        elem.tag = elem.constructor?.name;
        return elem;
    }
    static getLogger() {
        return new logger_1.Logger(logger_1.LoggerLevel.SILENT);
    }
}
exports.ElementTest = ElementTest;
//# sourceMappingURL=testing.js.map